Fragenbeispiele — excel2moodle 0.5.0 documentation

# Fragenbeispiele

## Vergleich der Fragen in Moodle und Tabelle

Im Folgenden werden Die Fragen, wie sie in der Tabelle erstellt werden, mit dem Ergebnis in Moodle gegenüber gestellt. Dadurch erhält man einen guten Eindruck, wie die Fragen am Ende aussehen.

### Multiple Choice Fragen

Example Kategorie 01 Multiple Choice Fragen
number | 1 | 2 | 3
type | MC | MC | MC
name | Farbe des Himmels | Kleines Ein Mal Eins | Längen Einheit
text | Welche Farbe hat der Himmel | Was steht im kleinen Ein Mal Eins | In welcher Einheit kann eine Länge angegeben werden.
text | Gehen sie von einem sonnigen unbewölkten Tag aus | Wählen Sie alle richtigen Ausdrücke aus |
text | Beachten sie alle Tageszeiten |  |
answerType | text | math | unit
true | blau | 7*7=49 | m
true | hellblau | 3*5=15 | cm
true | orange | 7*8=56 | inch
true | rot |  | dm
false | grün | 7*7=48 | psi
false | pink | 3*5=20 | bar
false | magenta | 7*8=54 | Mpa
false |  | 3*9=36 | kNm
false |  | a²+b²=c² | J

Zu sehen ist die Frage 2 wie sie in Moodle importiert ist.

Die normalen Nutzer sehen nur die beiden blauen Bereiche, nicht den Namen der Frage Es ist zu erkennen, wie die Antworten texte mit LaTex formatiert werden.

### Numerische Fragen

Note

Die Fragentypen `NF` (numerisches Format) und `NFM` (multi numerisches Format) werden als `numerical` in moodle exportiert. Sie unterscheiden sich daher nicht. Daher ist Die Tabelle oben identisch mit der unten, wenn die Fragenvariante 1 gewählt ist. Ansonsten unterscheiden sich die Zahlenwerte.

Die Tabelle Example Kategorie 02 Fragen NF und NFM Flächenberechnung zeigt gegenübergestellt eine NF und eine NFM Frage, die beide in Moodle identisch dargestellt werden. Das Ergebnis in Moodle zeigt das Bild unten Frage 1, bzw 2: Variante 1 wie sie in Moodle importiert ist.

Example Kategorie 02 Fragen NF und NFM Flächenberechnung
number | 1 | 2
type | NF | NFM
name | Berechnung Rechteck Flächeninhalt | Berechnung Rechteck Flächeninhalt
text | Berechnen Sie die den Flächeninhalt ( A ) des Rechtecks. | Berechnen Sie die den Flächeninhalt ( A ) des Rechtecks.
text | Gehen Sie dabei von folgenden Abmessungen des Rechtecks aus: | Gehen Sie dabei von folgenden Abmessungen des Rechtecks aus:
text | Das Ergebnis ist in (mathrm{[m²]}) anzugeben | Das Ergebnis ist in (mathrm{[m²]}) anzugeben
bulletPoint | Breite b = 2,1 m | Breite b = {breite} m
bulletPoint | Länge l = 3,4 m | Länge l = {lange} m
result | 7,14 | breite*lange
picture | 0 | 0
tolerance |  | 1,50
breite |  | 2,1; 2,5; 3,4
lange |  | 3,4; 3,8; 3,6
firstResult |  | 7,14

Frage 1, bzw 2: Variante 1 wie sie in Moodle importiert ist.

Es handelt sich um die Variante 1, zu erkennen, an dem ersten Satz an Variablen (b = 2,1; l = 3,4) Die normalen Nutzer sehen nur die beiden blauen Bereiche, nicht den Namen der Frage

Note

Werwendung von LaTeX

Die Vewendung von LaTex code ist durch die Syntax `\( a \cdot 10^{-2} \)` gekennzeichnet. Dies sieht wie folgt aus \(a \cdot 10^{-2}\). Hierbei wird alles innerhalb `\(` und `\)` als LaTex Formel dargestellt. Da Einheiten normalerweise nicht kursiv geschrieben werden, kann das LaTex Makro `\mathrm{ }` verwendet werden. Beispiel: `\( \mathrm{ [mm^2] } \)` wird zu: \(\mathrm{[mm^2]}\)

### Example of CLOZE questions

Example CLOZE Fragen Flächenberechnung
number | 1
type | CLOZE
name | Flächenberechnung, Inhalt und Umfang in einer Frage
text | Bestimmen Sie nacheinander die Unten aufgeführten Fragen.
text | Es geht um die Geometrie eines Rechtecks
text | Verwenden sie konsequent die Einheit (mathrm{[m]})
text | Gehen Sie dabei von folgenden Abmessungen des Rechtecks aus:
bulletPoint | Breite b = {breite} m
bulletPoint | Länge l = {lange} m
breite | 3; 2,5; 3,4
lange | 4; 3,8; 3,6
picture | true
WrongSignCount | 50
Part:1 | Bestimmen sie den Flächeninhalt ( A )
Result:1 | breite*lange
Points:1 |
FirstResult:1 | 12
Part:2 | Bestimmen sie den Rechteck Umfang
Result:2 | 2*(lange+breite)
Points:2 |
FirstResult:2 | 14
Part:3 | Bestimmen Sie die Diagonale (d)
Result:3 | sqrt(lange**2+breite**2)
First Result:3 | 5

Zu sehen ist die CLOZE Frage. Es handelt sich um die gleichen Fragen wie bei der NFM Frage, nur ist hier noch ein zweiter Teil angefügt, der nach dem Rechteckumfang fragt.

An der Bewertung ist zu sehen, dass `wrongSignCount=50` zu der halben Punktzahl bei der Antwort mit falschem Vorzeichen führt. Außerdem ist zu sehen, dass \(1\%\) Antwort Toleranz angewendet wurde.

## Example for a ``MC`` Question

A | B | C
--- | --- | ---
number | 1 | 2
type | MC | MC
name | Multiple Choice | second multiple Choice
text | Select the right Options | Click on the correct answers
text | The rectangle has those dimensions: | The rectangle has those dimensions:
answerType | text | text
true | right Answer | correct
true | another correct One | right
true |  | right again
false | bullshit | incorrect
false | wrong | not right
false | wrong again | wrong

## Example for a ``NF`` Question

A | B | C
--- | --- | ---
number | 1 | 2
type | NF | NF
name | Area Calculation | Circumference Calculation
text | calculate the area of the rectangle | Calculate the circumference of the rectangle
text | the result should be in meters [m] | the result should be in meters [m]
text | The rectangle has those dimensions: | The rectangle has those dimensions:
bulletPoint | length a = 5 m | length a = 5 m
bulletPoint | with b = 2 m | width b = 2 m
result | 10 | 14

## Example for a ``NFM`` Question

A | B | C
number | 1 | 2
type | NFM | NFM
name | Area Calculation | Circumference Calculation
text | calculate the area of the rectangle | Calculate the circumference of the rectangle
text | the result should be in meters [m] | the result should be in meters [m]
text | The rectangle has those dimensions: | The rectangle has those dimensions:
bulletPoint | length a = {a} m | length a = {a} m
bulletPoint | width b = {b} m | width b = {b} m
result | a * b | 2*a + 2*b
a | 5;3;7 | 5;3;7
b | 2;2;1 | 2;2;1
firstResult | 10 | 14